==> Data-Scan-0.002.tar.gz: Data-Scan-0.002/lib/Data/Scan/Printer.pm <==
use strict;
use warnings FATAL => 'all';

package Data::Scan::Printer;

# ABSTRACT: Data::Scan::Printer - Example of a printer consumer for Data::Scan

our $VERSION = '0.002'; # VERSION

# AUTHORITY

use Exporter qw/import/;
use vars qw/@EXPORT/;
use Data::Scan::Impl::Printer;
use Moo;
extends 'Data::Scan';
#
# Using this module intentionaly means caller is ok to pollute its namespace
#
@EXPORT = qw/dspp/;


sub dspp {
  my $consumer = Data::Scan::Impl::Printer->new(%Data::Scan::Printer::Option);
  __PACKAGE__->new(consumer => $consumer)->process(@_);
  print $consumer->output
}


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Scan::Printer - Data::Scan::Printer - Example of a printer consumer for Data::Scan

=head1 VERSION

version 0.002

=head1 SYNOPSIS

    use strict;
    use warnings FATAL => 'all';
    use Data::Scan::Printer;

    my $this = bless([ 'var1', 'var2', {'a' => 'b', 'c' => 'd'}, \undef, \\undef, [] ], 'TEST');
    dspp($this);

=head1 DESCRIPTION

Data::Scan::Printer is polluting user's namespace with a dspp() method, showing our Data::Scan can be used to dump an arbitrary structure.

=head1 SUBROUTINES/METHODS

=head2 dspp(@arguments)

Print to STDOUT a dumped vision of the arguments.

=head1 SEE ALSO

L<Data::Printer>

=head1 AUTHOR

Jean-Damien Durand <jeandamiendurand@free.fr>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Jean-Damien Durand.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Data-Scan-0.003.tar.gz: Data-Scan-0.003/lib/Data/Scan/Printer.pm <==
use strict;
use warnings FATAL => 'all';

package Data::Scan::Printer;

# ABSTRACT: Data::Scan::Printer - Example of a printer consumer for Data::Scan

our $VERSION = '0.003'; # VERSION

# AUTHORITY

use Exporter qw/import/;
use vars qw/@EXPORT/;
use Data::Scan::Impl::Printer;
use Moo;
extends 'Data::Scan';
#
# Using this module intentionaly means caller is ok to pollute its namespace
#
@EXPORT = qw/dspp/;


sub dspp {
  my $consumer = Data::Scan::Impl::Printer->new(%Data::Scan::Printer::Option);
  __PACKAGE__->new(consumer => $consumer)->process(@_);
  #
  # We know this consumer has a dsoutput method
  #
  print $consumer->dsoutput
}


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Scan::Printer - Data::Scan::Printer - Example of a printer consumer for Data::Scan

=head1 VERSION

version 0.003

=head1 SYNOPSIS

    use strict;
    use warnings FATAL => 'all';
    use Data::Scan::Printer;

    my $this = bless([ 'var1', 'var2', {'a' => 'b', 'c' => 'd'}, \undef, \\undef, [] ], 'TEST');
    dspp($this);

=head1 DESCRIPTION

Data::Scan::Printer is polluting user's namespace with a dspp() method, showing our Data::Scan can be used to dump an arbitrary structure.

=head1 SUBROUTINES/METHODS

=head2 dspp(@arguments)

Print to STDOUT a dumped vision of the arguments.

=head1 SEE ALSO

L<Data::Printer>

=head1 AUTHOR

Jean-Damien Durand <jeandamiendurand@free.fr>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Jean-Damien Durand.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
